@@ -3,9 +3,7 @@
 // findKey("key:") - first ws-delimited field following key. initial ws before
 //                   key should not be specified: skipped by findKey.
 
-string ConfigFile::findKey(string const &key, size_t idx) const
+string ConfigFile::findKey(string const &keyPattern, size_t count)
 {
-    static Pattern pattern("^\\s*\\S+\\s+(\\S+)");  // pick 2nd term as [1]
-
-    return searchFor(key, pattern, idx);
+    return searchFor("^\\s*" + keyPattern + "\\s+(\\S+)", count);
 }
