@@ -3,17 +3,19 @@
 void ConfigFile::open(string const &fname)
 {
     ifstream stream;
-    Msg::open(stream, fname);
+    Errno::open(stream, fname);
 
-    clear();                        // clear the vector
+    d_line.clear();                 // clear the vector
     d_index.clear();                // clear the line indices
+    d_vsIter.clear();
+
     d_rawIndex = 0;                 // initialize the line-index of the
                                     // original file
 
     string line;
 
     while (nextLine(stream, line))
-        push_back(line);
+        d_line.push_back(line);
 }
 
 
