@@ -12,16 +12,20 @@ Process::ExecContext Process::analyzeCommand()
                                             // set up a process struct
     ExecContext ec = {true, 0, 0, new char const *[count + 1]};
     
-    for_each(elements.begin(), elements.end(), 
-                               FnWrap::unary(execContext, ec));
+    for_each(
+        elements.begin(), elements.end(), 
+        [&](String::SplitPair const &splitPair)
+        {
+            execContext(splitPair, ec);
+        }
+    );
     
     if (!ec.ok)
-        throw Errno("Process ") << insertable << d_command << ": " << 
-                                                ec.message << throwable;
+        throw Errno("Process ") << d_command << ": " << ec.message;
     
     if (!ec.argc)
-        throw Errno("Process: can't execute ") << insertable << d_command <<
-                                                                    throwable;
+        throw Errno("Process: can't execute ") << d_command;
+
     ec.args[ec.argc] = 0;
      
     return ec;
